@@ -1,5 +1,5 @@
 package WebService::HackerNews;
-$WebService::HackerNews::VERSION = '0.04';
+$WebService::HackerNews::VERSION = '0.05';
 use 5.006;
 use Moo;
 use JSON qw(decode_json);
@@ -189,7 +189,7 @@ L<API Documentation|https://github.com/HackerNews/API>.
 
 =head1 REPOSITORY
 
-L<https://github.com/neilbowers/WebService-HackerNews>
+L<https://github.com/neilb/WebService-HackerNews>
 
 =head1 AUTHOR
 
